@@ -10,6 +10,18 @@ from slugify import slugify
 from api_reflector import auth, db, models
 
 
+def admin_view(model: db.Model):
+    """
+    Registers a model with the admin.
+    """
+
+    def decorator(cls):
+        admin.add_view(cls(model, db.session))
+        return cls
+
+    return decorator
+
+
 class RestrictedAdminView(AdminIndexView):
     """
     Overrides default Flask-Admin admin view to implement OSS authentication before accessing.
@@ -40,17 +52,21 @@ class RestrictedView(ModelView):
         return redirect(url_for("azure.login"))
 
 
+@admin_view(models.Tag)
 class TagView(RestrictedView):
     """
     Admin modelview for the Tag model.
     """
 
+    form_excluded_columns = ("responses",)
+
     def validate_form(self, form):
-        if hasattr(form, "name") and form.name.data:
-            form.name.data = slugify(form.name.data)
+        if form.data.get("name"):
+            form.name.data = slugify(form.data["name"])
         return super().validate_form(form)
 
 
+@admin_view(models.Endpoint)
 class EndpointView(RestrictedView):
     """
     Admin modelview for the Endpoint model.
@@ -58,15 +74,21 @@ class EndpointView(RestrictedView):
 
     form_excluded_columns = ("responses",)
     form_widget_args = {"responses": {"disabled": True}}
-    inline_models = (models.Response,)
+
+    def validate_form(self, form):
+        if form.data.get("path") and not form.data["path"].startswith("/"):
+            form.path.data = f"/{form.data['path']}"
+        return super().validate_form(form)
+
+
+@admin_view(models.Response)
+class ResponseView(RestrictedView):
+    """
+    Admin modelview for the Response model.
+    """
+
+    column_exclude_list = ("content_type",)
+    inline_models = (models.Rule, models.Action)
 
 
 admin.add_link(MenuLink(name="Home", url="/"))
-
-admin.add_views(
-    TagView(models.Tag, db.session),
-    EndpointView(models.Endpoint, db.session),
-    RestrictedView(models.Response, db.session),
-    RestrictedView(models.Rule, db.session),
-    RestrictedView(models.Action, db.session),
-)
